@@ -65,6 +65,15 @@ struct {
 uint16_t strong_magnitude;
 uint16_t weak_magnitude;
 } ATTRIBUTE_PACKED rumble;
+struct {
+uint16_t hid_usage;
+uint16_t vendor_id;
+unsigned char vendor_waveform_page;
+unsigned char mpers_filler_3[1];
+uint16_t intensity;
+uint16_t repeat_count;
+uint16_t retrigger_period;
+} ATTRIBUTE_PACKED haptic;
 } u;
 } ATTRIBUTE_PACKED m32_struct_ff_effect;
 #define MPERS_m32_struct_ff_effect m32_struct_ff_effect
